==> aws-sdk-cpp-1.11.667-1-x86_64.pkg.tar.zst: usr/include/aws/backup-gateway/BackupGatewayEndpointProvider.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/backup-gateway/BackupGateway_EXPORTS.h>
#include <aws/core/client/GenericClientConfiguration.h>
#include <aws/core/endpoint/DefaultEndpointProvider.h>
#include <aws/core/endpoint/EndpointParameter.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>

#include <aws/backup-gateway/BackupGatewayEndpointRules.h>


namespace Aws
{
namespace BackupGateway
{
namespace Endpoint
{
using EndpointParameters = Aws::Endpoint::EndpointParameters;
using Aws::Endpoint::EndpointProviderBase;
using Aws::Endpoint::DefaultEndpointProvider;

using BackupGatewayClientContextParameters = Aws::Endpoint::ClientContextParameters;

using BackupGatewayClientConfiguration = Aws::Client::GenericClientConfiguration;
using BackupGatewayBuiltInParameters = Aws::Endpoint::BuiltInParameters;

/**
 * The type for the BackupGateway Client Endpoint Provider.
 * Inherit from this Base class / "Interface" should you want to provide a custom endpoint provider.
 * The SDK must use service-specific type for each service per specification.
 */
using BackupGatewayEndpointProviderBase =
    EndpointProviderBase<BackupGatewayClientConfiguration, BackupGatewayBuiltInParameters, BackupGatewayClientContextParameters>;

using BackupGatewayDefaultEpProviderBase =
    DefaultEndpointProvider<BackupGatewayClientConfiguration, BackupGatewayBuiltInParameters, BackupGatewayClientContextParameters>;

/**
 * Default endpoint provider used for this service
 */
class AWS_BACKUPGATEWAY_API BackupGatewayEndpointProvider : public BackupGatewayDefaultEpProviderBase
{
public:
    using BackupGatewayResolveEndpointOutcome = Aws::Endpoint::ResolveEndpointOutcome;

    BackupGatewayEndpointProvider()
      : BackupGatewayDefaultEpProviderBase(Aws::BackupGateway::BackupGatewayEndpointRules::GetRulesBlob(), Aws::BackupGateway::BackupGatewayEndpointRules::RulesBlobSize)
    {}

    ~BackupGatewayEndpointProvider()
    {
    }
};
} // namespace Endpoint
} // namespace BackupGateway
} // namespace Aws

==> aws-sdk-cpp-1.11.710-1-x86_64.pkg.tar.zst: usr/include/aws/backup-gateway/BackupGatewayEndpointProvider.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/backup-gateway/BackupGatewayEndpointRules.h>
#include <aws/backup-gateway/BackupGateway_EXPORTS.h>
#include <aws/core/client/GenericClientConfiguration.h>
#include <aws/core/endpoint/DefaultEndpointProvider.h>
#include <aws/core/endpoint/EndpointParameter.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>

namespace Aws {
namespace BackupGateway {
namespace Endpoint {
using EndpointParameters = Aws::Endpoint::EndpointParameters;
using Aws::Endpoint::DefaultEndpointProvider;
using Aws::Endpoint::EndpointProviderBase;

using BackupGatewayClientContextParameters = Aws::Endpoint::ClientContextParameters;

using BackupGatewayClientConfiguration = Aws::Client::GenericClientConfiguration;
using BackupGatewayBuiltInParameters = Aws::Endpoint::BuiltInParameters;

/**
 * The type for the BackupGateway Client Endpoint Provider.
 * Inherit from this Base class / "Interface" should you want to provide a custom endpoint provider.
 * The SDK must use service-specific type for each service per specification.
 */
using BackupGatewayEndpointProviderBase =
    EndpointProviderBase<BackupGatewayClientConfiguration, BackupGatewayBuiltInParameters, BackupGatewayClientContextParameters>;

using BackupGatewayDefaultEpProviderBase =
    DefaultEndpointProvider<BackupGatewayClientConfiguration, BackupGatewayBuiltInParameters, BackupGatewayClientContextParameters>;

/**
 * Default endpoint provider used for this service
 */
class AWS_BACKUPGATEWAY_API BackupGatewayEndpointProvider : public BackupGatewayDefaultEpProviderBase {
 public:
  using BackupGatewayResolveEndpointOutcome = Aws::Endpoint::ResolveEndpointOutcome;

  BackupGatewayEndpointProvider()
      : BackupGatewayDefaultEpProviderBase(Aws::BackupGateway::BackupGatewayEndpointRules::GetRulesBlob(),
                                           Aws::BackupGateway::BackupGatewayEndpointRules::RulesBlobSize) {}

  ~BackupGatewayEndpointProvider() {}
};
}  // namespace Endpoint
}  // namespace BackupGateway
}  // namespace Aws
